
/* Generated data (by glib-mkenums) */

#ifndef GIGGLE_ENUMERATIONS_H
#define GIGGLE_ENUMERATIONS_H

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "giggle-remote-branch.h" */
GType giggle_remote_direction_get_type (void);
#define GIGGLE_TYPE_REMOTE_DIRECTION (giggle_remote_direction_get_type())
/* enumerations from "giggle-git-list-files.h" */
GType giggle_git_list_files_status_get_type (void);
#define GIGGLE_TYPE_GIT_LIST_FILES_STATUS (giggle_git_list_files_status_get_type())
G_END_DECLS

#endif /* !GIGGLE_ENUMERATIONS_H */

/* Generated data ends here */

